<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl_NL">
<context>
    <name>CreateFieldDialog</name>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1049"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1062"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1072"/>
        <source>String</source>
        <translation>String</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1073"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1074"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1075"/>
        <source>Number</source>
        <translation>Nummer</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1076"/>
        <source>Phone Number</source>
        <translation>Telefoonnummer</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1077"/>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1078"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1083"/>
        <source>Order</source>
        <translation>Volgorde</translation>
    </message>
</context>
<context>
    <name>DetailWindow</name>
    <message>
        <location filename="../../DetailedWindow.cpp" line="63"/>
        <source>Copy of </source>
        <translation>Kopie van</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="110"/>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="112"/>
        <location filename="../../DetailedWindow.cpp" line="739"/>
        <location filename="../../DetailedWindow.cpp" line="752"/>
        <source>Delete</source>
        <translation>Verwijder</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="113"/>
        <source>Change Face Pict.</source>
        <translation>Wijzig pasfoto</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="114"/>
        <source>Mirror Face Pict.</source>
        <translation>Draai pasfoto</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="115"/>
        <source>Change Back Pict.</source>
        <translation>Wijzig achtergr. foto</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="116"/>
        <source>Mirror Back Pict.</source>
        <translation>Draai achtergr. foto</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="117"/>
        <source>Delete Face Pict.</source>
        <translation>Verwijder pasfoto</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="118"/>
        <source>Delete Back Pict.</source>
        <translation>Verwijder achtergr. foto</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="119"/>
        <source>Modify fields</source>
        <translation>Wijzig velden</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="124"/>
        <source>New Card</source>
        <translation>Nieuwe kaart</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="125"/>
        <source>Edit Card</source>
        <translation>Bewerk kaart</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="126"/>
        <source>New Card like this</source>
        <translation>Nieuwe kaart zoals deze</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="127"/>
        <source>Duplicate Card</source>
        <translation>Kopieer kaart</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="128"/>
        <source>Export Face Pict.</source>
        <translation>Exporteer pasfoto</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="129"/>
        <source>Export Back Pict.</source>
        <translation>Exporteer achtergr. foto</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="156"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="167"/>
        <source>Group Name</source>
        <translation>Groepnaam</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="185"/>
        <source>Membership Info</source>
        <translation>Info lidmaatschap</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="186"/>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="187"/>
        <source>Credit Card</source>
        <translation>Creditcard</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="188"/>
        <source>Bank Account</source>
        <translation>Bankrekening</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="189"/>
        <source>Health Numbers</source>
        <translation>Gezondheidsnummers</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="190"/>
        <source>Passport Info</source>
        <translation>Info paspoort</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="191"/>
        <source>Note Card</source>
        <translation>Notitiekaart</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="192"/>
        <source>Car Info</source>
        <translation>Kaart info</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="193"/>
        <source>Cellular Phone</source>
        <translation>Mobiele telefoon</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="194"/>
        <source>Serial Number Software</source>
        <translation>Serienummer software</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="195"/>
        <source>Serial Number Hardware</source>
        <translation>Serienummer hardware</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="196"/>
        <source>Web site</source>
        <translation>Website</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="197"/>
        <source>ID Card</source>
        <translation>ID kaart</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="198"/>
        <source>Social Security Number</source>
        <translation>Sociale verzekeringsnummer</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="199"/>
        <source>Email Account</source>
        <translation>E-mail account</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="200"/>
        <source>Driver&apos;s License</source>
        <translation>Rijbewijs</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="201"/>
        <source>Others</source>
        <translation>Anders</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="205"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="473"/>
        <location filename="../../DetailedWindow.cpp" line="519"/>
        <source>Click to see</source>
        <translation>Klik om te bekijken</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="573"/>
        <source>Card description is missing</source>
        <translation>Kaartbeschrijving ontbreekt</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="583"/>
        <source>Type card is missing</source>
        <translation>Type kaart ontbreekt</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="737"/>
        <location filename="../../DetailedWindow.cpp" line="750"/>
        <source>Edit</source>
        <translation>Bewerk</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="738"/>
        <location filename="../../DetailedWindow.cpp" line="751"/>
        <source>Mirror</source>
        <translation>Draai</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="742"/>
        <source>Export Face</source>
        <translation>Exporteer voorkant</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="755"/>
        <source>Export Back</source>
        <translation>Exporteer achterkant</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="773"/>
        <source>Choose card face image file</source>
        <translation>Kies bestand voorkant kaart</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="775"/>
        <location filename="../../DetailedWindow.cpp" line="913"/>
        <source>Images (*.png);;</source>
        <translation>Afbeeldingen PNG (*.png)</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="787"/>
        <source>Choose card face image</source>
        <translation>Kies afbeelding voorkant kaart</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="789"/>
        <location filename="../../DetailedWindow.cpp" line="928"/>
        <source>Images (*.png *.jpg *.gif *.jpeg);;</source>
        <translation>Afbeeldingen (*.png *.jpg *.gif *.jpeg)</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="911"/>
        <source>Choose card back image file</source>
        <translation>Kies bestand achterkant kaart</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="926"/>
        <source>Choose card back image</source>
        <translation>Kies afbeelding achterkant kaart</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="966"/>
        <source>Are you sure you want to discard changes?</source>
        <translation>Wijzigingen niet doorvoeren?</translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <location filename="../../LoginDialog.cpp" line="97"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="105"/>
        <source>Clear</source>
        <translation>Wis</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="149"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="157"/>
        <source>Donate</source>
        <translation>Doneer</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="165"/>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="221"/>
        <source>About Wallet</source>
        <translation>Over Wallet</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="239"/>
        <source>Password is required</source>
        <translation>Wachtwoord benodigd</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="256"/>
        <source>For verification, please, enter your password again</source>
        <translation>Voer uw wachtwoord ter verificatie nogmaals in</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="269"/>
        <source>Invalid password, please enter again</source>
        <translation>Wachtwoord onjuist, probeer nogmaals</translation>
    </message>
</context>
<context>
    <name>RenameGroupDialog</name>
    <message>
        <location filename="../../eWallet.cpp" line="49"/>
        <source>Save &amp;&amp; Close</source>
        <translation>Opslaan &amp;&amp; sluiten</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="62"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
</context>
<context>
    <name>eWallet</name>
    <message>
        <location filename="../../eWallet.cpp" line="444"/>
        <source>Are you sure you want to remove all your data? You will lost all your data</source>
        <translation>Alle data verwijderen? Alle informatie zal verloren gaan!</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="469"/>
        <source>Wrong password</source>
        <translation>Onjuist wachtwoord</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="366"/>
        <location filename="../../eWallet.cpp" line="819"/>
        <source>&lt;All&gt;</source>
        <translation>&lt;Alle&gt;</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="385"/>
        <location filename="../../eWallet.cpp" line="828"/>
        <source>&lt;No Group&gt;</source>
        <translation>&lt;Geen groep&gt;</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="529"/>
        <source>Organization</source>
        <translation>Organisatie</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="530"/>
        <location filename="../../eWallet.cpp" line="551"/>
        <location filename="../../eWallet.cpp" line="601"/>
        <source>Phone Number</source>
        <translation>Telefoonnummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="531"/>
        <location filename="../../eWallet.cpp" line="565"/>
        <source>Other Information</source>
        <translation>Andere informatie</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="532"/>
        <location filename="../../eWallet.cpp" line="541"/>
        <location filename="../../eWallet.cpp" line="643"/>
        <source>User Name</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="533"/>
        <location filename="../../eWallet.cpp" line="542"/>
        <location filename="../../eWallet.cpp" line="569"/>
        <location filename="../../eWallet.cpp" line="600"/>
        <location filename="../../eWallet.cpp" line="629"/>
        <location filename="../../eWallet.cpp" line="640"/>
        <location filename="../../eWallet.cpp" line="644"/>
        <location filename="../../eWallet.cpp" line="653"/>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="534"/>
        <source>Organization club</source>
        <translation>Organisatie club</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="535"/>
        <location filename="../../eWallet.cpp" line="568"/>
        <location filename="../../eWallet.cpp" line="634"/>
        <source>ID Number</source>
        <translation>ID nummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="536"/>
        <location filename="../../eWallet.cpp" line="543"/>
        <location filename="../../eWallet.cpp" line="608"/>
        <location filename="../../eWallet.cpp" line="627"/>
        <location filename="../../eWallet.cpp" line="652"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="537"/>
        <location filename="../../eWallet.cpp" line="557"/>
        <location filename="../../eWallet.cpp" line="571"/>
        <location filename="../../eWallet.cpp" line="646"/>
        <location filename="../../eWallet.cpp" line="656"/>
        <source>Card Notes</source>
        <translation>Kaartnotities</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="540"/>
        <location filename="../../eWallet.cpp" line="645"/>
        <source>System</source>
        <translation>Systeem</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="546"/>
        <source>Credit Card Type</source>
        <translation>Type creditcard</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="547"/>
        <source>Card Provider</source>
        <translation>Kaartleverancier</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="548"/>
        <source>Card Number</source>
        <translation>Kaartnummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="549"/>
        <location filename="../../eWallet.cpp" line="554"/>
        <location filename="../../eWallet.cpp" line="651"/>
        <source>Expiration Date</source>
        <translation>Vervaldatum</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="550"/>
        <source>Name on Card</source>
        <translation>Naam op kaart</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="552"/>
        <location filename="../../eWallet.cpp" line="563"/>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="553"/>
        <source>Start Date</source>
        <translation>Startdatum</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="555"/>
        <source>Detail</source>
        <translation>Detail</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="556"/>
        <source>3-digit CVC#</source>
        <translation>CVC nr. (3 nummers)</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="560"/>
        <source>Bank Name</source>
        <translation>Naam bank</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="561"/>
        <source>Account Number</source>
        <translation>Account nummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="562"/>
        <source>Telephone</source>
        <translation>Telefoon</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="564"/>
        <source>SWIFT Code</source>
        <translation>SWIFT code</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="570"/>
        <location filename="../../eWallet.cpp" line="635"/>
        <source>Card Title</source>
        <translation>Kaart titel</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="574"/>
        <source>Passport No</source>
        <translation>Paspoortnummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="575"/>
        <source>Surname</source>
        <translation>Achternaam</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="576"/>
        <source>Given names</source>
        <translation>Voornamen</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="577"/>
        <source>Date of birth</source>
        <translation>Verjaardag</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="578"/>
        <source>Date of issue</source>
        <translation>Datum van uitgave</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="579"/>
        <source>Date of expiration</source>
        <translation>Verloopdatum</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="580"/>
        <source>Authority</source>
        <translation>Authoriteit</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="583"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="586"/>
        <location filename="../../eWallet.cpp" line="590"/>
        <source>Model</source>
        <translation>Model</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="587"/>
        <source>Vehicle Number</source>
        <translation>Voertuignummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="591"/>
        <source>Brand</source>
        <translation>Merk</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="592"/>
        <source>IMEI#</source>
        <translation>IMEI nr.</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="593"/>
        <source>Firmware code</source>
        <translation>Firmware code</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="594"/>
        <source>Purchased</source>
        <translation>Gekocht</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="595"/>
        <source>Pin1</source>
        <translation>PIN 1</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="596"/>
        <source>Pin2</source>
        <translation>PIN 2</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="597"/>
        <source>Puk1</source>
        <translation>PUK 1</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="598"/>
        <source>Puk2</source>
        <translation>PUK 2</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="599"/>
        <source>Num SIM</source>
        <translation>SIM nr.</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="602"/>
        <source>Manufacturer</source>
        <translation>Fabrikant</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="605"/>
        <location filename="../../eWallet.cpp" line="619"/>
        <source>Product</source>
        <translation>Product</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="606"/>
        <source>Version</source>
        <translation>Versie</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="607"/>
        <location filename="../../eWallet.cpp" line="620"/>
        <source>Serial #</source>
        <translation>Serienummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="609"/>
        <source>Company</source>
        <translation>Bedrijf</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="610"/>
        <source>Date bought</source>
        <translation>Datum aanschaf</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="611"/>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="612"/>
        <location filename="../../eWallet.cpp" line="628"/>
        <source>Login</source>
        <translation>Inloggen</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="613"/>
        <source>Authorization key</source>
        <translation>Beveiliginssleutel</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="614"/>
        <location filename="../../eWallet.cpp" line="623"/>
        <source>Price paid</source>
        <translation>Prijs</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="615"/>
        <source>Support</source>
        <translation>Ondersteuning</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="616"/>
        <location filename="../../eWallet.cpp" line="631"/>
        <source>Notes</source>
        <translation>Notities</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="621"/>
        <source>Model #</source>
        <translation>Modelnummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="622"/>
        <source>Bought from</source>
        <translation>Gekocht van</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="624"/>
        <source>Guarantee period</source>
        <translation>Garantieperiode</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="630"/>
        <source>E mail used</source>
        <translation>E-mail gebruikt</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="638"/>
        <source>Social Security Number</source>
        <translation>Sociaal verzekeringsnummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="639"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="649"/>
        <source>Driver&apos;s License Number</source>
        <translation>Rijbewijsnummer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="650"/>
        <source>Date Issued</source>
        <translation>Datum uitgave</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="908"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="910"/>
        <source>Delete DB</source>
        <translation>Verwijder database</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="912"/>
        <location filename="../../eWallet.cpp" line="923"/>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="915"/>
        <source>New</source>
        <translation>Nieuw</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="917"/>
        <location filename="../../eWallet.cpp" line="1391"/>
        <source>Edit</source>
        <translation>Bewerk</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="918"/>
        <source>Invert Sort</source>
        <translation>Omgekeerd sorteren</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="919"/>
        <source>Import</source>
        <translation>Importeren</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="920"/>
        <source>Export</source>
        <translation>Exporteren</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="922"/>
        <source>Change Password</source>
        <translation>Wijzig wachtwoord</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="982"/>
        <source>Are you sure you want to remove it?</source>
        <translation>Weet u zeker dat u dit wilt verwijderen?</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1130"/>
        <source>Choose import file</source>
        <translation>Kies importbestand</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1132"/>
        <location filename="../../eWallet.cpp" line="1407"/>
        <source>Text files (*.txt);;</source>
        <translation>Tekstbestanden (*.txt)</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1380"/>
        <source>Rename</source>
        <translation>Hernoem</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1381"/>
        <location filename="../../eWallet.cpp" line="1394"/>
        <source>Delete</source>
        <translation>Verwijder</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1390"/>
        <source>View</source>
        <translation>Bekijk</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1392"/>
        <source>New like this</source>
        <translation>Nieuwe zoals deze</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1393"/>
        <source>Duplicate</source>
        <translation>Kopieer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1405"/>
        <source>Choose export file</source>
        <translation>Kies exportbestand</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1610"/>
        <source>About Wallet</source>
        <translation>Over Wallet</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1645"/>
        <source>Changing password, please wait until application quits</source>
        <translation>Wijzigt wachtwoord. Wacht a.u.b. tot applicatie afsluit</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1651"/>
         <source>Password changed successfully, application will exit</source>
        <translation>Wachtwoord succesvol gewijzigd. Applicatie zal afsluiten</translation>
        
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1653"/>
        <source>Password CANNOT BE changed, because %1, and application will exit</source>
        <translation>Wachtwoord NIET gewijzigd vanwege %1. Applicatie zal afsluiten</translation>
    </message>
</context>
</TS>
